@@ -47,6 +47,10 @@ class QuantumNovaIPAMLib(object):
         """
         self.net_manager = net_manager
 
+        # NOTE(s0mik) : If DHCP is not in use, we need to timeout IPs
+        # periodically.  See comment in deallocate_ips_by_vif for more
+        self.net_manager.timeout_fixed_ips = not self.net_manager.DHCP
+
     def create_subnet(self, context, label, tenant_id,
                       quantum_net_id, priority, cidr=None,
                       gateway=None, gateway_v6=None, cidr_v6=None,
@@ -213,6 +217,17 @@ class QuantumNovaIPAMLib(object):
         admin_context = context.elevated()
         fixed_ips = db.fixed_ips_by_virtual_interface(admin_context,
                                                          vif_ref['id'])
+        # NOTE(s0mik): Sets fixed-ip to deallocated, but leaves the entry
+        # associated with the instance-id.  This prevents us from handing it
+        # out again immediately, as allocating it to a new instance before
+        # a DHCP lease has timed-out is bad.  Instead, the fixed-ip will
+        # be disassociated with the instance-id by a call to one of two
+        # methods inherited from FlatManager:
+        # - if DHCP is in use, a lease expiring in dnsmasq triggers
+        #   a call to release_fixed_ip in the network manager.
+        # - otherwise, _disassociate_stale_fixed_ips is called periodically
+        #   to disassociate all fixed ips that are unallocated
+        #   but still associated with an instance-id.
         for fixed_ip in fixed_ips:
             db.fixed_ip_update(admin_context, fixed_ip['address'],
                                {'allocated': False,
